; Procedure to extrapolate coefficients of the
; International Geomagnetic Reference Field. 

 PRO IGRFDIPOLE,dev=dev,fitst=fitst,fitend=fitend
 
 
  dstr=''
  numyear=21
  
  ddtor=!dpi/180.0d
  
  year=DBLARR(numyear)
  g10=DBLARR(numyear)
  g11=DBLARR(numyear)
  h11=DBLARR(numyear)
  rg10=0.0d & rg11=0.0d & rh11=0.0d

 
  OPENR,unit,'IGRFtable1.txt',/GET
  READF,unit,form='(A8,21f0.0)',dstr,year
  READF,unit,form='(A8,22f0.0)',dstr,g10,rg10
  READF,unit,form='(A8,22f0.0)',dstr,g11,rg11
  READF,unit,form='(A8,22f0.0)',dstr,h11,rh11
  
  FREE_LUN,unit
 
  year=[year,year(numyear-1)+5.0]-2000.0
  g10=[g10,g10(numyear-1)+rg10*5]
  g11=[g11,g11(numyear-1)+rg11*5]
  h11=[h11,h11(numyear-1)+rh11*5]
 
  lon=(atan(h11,g11)+!dpi)/ddtor
  lat= (((!dpi/2.0d) - atan( ( g11*cos(lon*ddtor) + h11*sin(lon*ddtor) ) / g10 )))/ddtor
  re=6378.14
  mom= SQRT(g10*g10+g11*g11+h11*h11)/1.0e5 ;T*Re^3
   
  ; fit parameter:
  IF NOT KEYWORD_SET(fitst) THEN fitst=15
  IF NOT KEYWORD_SET(fitend) THEN fitend=numyear
  yfit=year(fitst:fitend)
  lfit=lon(fitst:fitend)
  FREGCO,yfit,g10(fitst:fitend),a_g10,b_g10
  FREGCO,yfit,g11(fitst:fitend),a_g11,b_g11
  FREGCO,yfit,h11(fitst:fitend),a_h11,b_h11
  FREGCO,yfit,lat(fitst:fitend),a_lat,b_lat
  FREGCO,yfit,lon(fitst:fitend),a_lon,b_lon
  FREGCO,yfit,mom(fitst:fitend),a_mom,b_mom
  
  flon=atan(a_h11*yfit+b_h11,a_g11*yfit+b_g11)/ddtor+180.0d
  flat= ((!dpi/2.0d) - atan( ((a_g11*yfit+b_g11) *cos(flon*ddtor) + (a_h11*yfit+b_h11)*sin(flon*ddtor) ) $
    / (a_g10*yfit+b_g10) ))/ddtor

  DEFAULTSTR,d
  IF NOT KEYWORD_SET(dev) THEN d.devicename='X' ELSE d.devicename='ps'
  d.filename='igrfdipole'
  d.yoffset=1.5
  OPENDEVICE,d
  

  !p.multi=[7,0,7,0,0]
  PLOT,lon,((90.0d)-lat),xr=[288,292],yr=[11.6,10.0],xst=1,yst=1,$
    ytit='lat',xtit='lon'
  OPLOT,flon,((90.0d)-flat),linest=1
  PLOT,year,g10,ytit='g10'
  OPLOT,yfit,a_g10*yfit+b_g10,linest=1
  XYOUTS,yfit(0),a_g10*yfit(0)+b_g10,'a:'+STRTRIM(a_g10,2)+' b:'+STRTRIM(b_g10,2)
  PLOT,year,g11,ytit='g11'
  OPLOT,yfit,a_g11*yfit+b_g11,linest=1
  XYOUTS,yfit(0),a_g11*yfit(0)+b_g11,'a:'+STRTRIM(a_g11,2)+' b:'+STRTRIM(b_g11,2)
  PLOT,year,h11,yr=[5000,6000],yst=1,ytit='h11'
  OPLOT,yfit,a_h11*yfit+b_h11,linest=1
  XYOUTS,yfit(0),a_h11*yfit(0)+b_h11,'a:'+STRTRIM(a_h11,2)+' b:'+STRTRIM(b_h11,2)
  PLOT,year,lat,ytit='lat',yr=[78,80],yst=1
  OPLOT,yfit,a_lat*yfit+b_lat,linest=1
  XYOUTS,yfit(0),a_lat*yfit(0)+b_lat,'a:'+STRTRIM(a_lat,2)+' b:'+STRTRIM(b_lat,2)
  XYOUTS,year(0),78,'MaxDev:'+STRTRIM(MAX(ABS(a_lat*yfit+b_lat-lat(fitst:fitend))))
  PLOT,year,lon,ytit='lon',yr=[288,292],yst=1,xtit='Years from J2000.0'
  OPLOT,yfit,a_lon*yfit+b_lon,linest=1
  XYOUTS,yfit(0),a_lon*yfit(0)+b_lon,'a:'+STRTRIM(a_lon,2)+' b:'+STRTRIM(b_lon,2)
  XYOUTS,year(0),288,'MaxDev:'+STRTRIM(MAX(ABS(a_lon*yfit+b_lon-lon(fitst:fitend))))
  PLOT,year,mom,ytit='mom',yr=[0.33,0.30],yst=1,xtit='Years from J2000.0'
  OPLOT,yfit,a_mom*yfit+b_mom,linest=1
  XYOUTS,yfit(0),a_mom*yfit(0)+b_mom,'a:'+STRTRIM(a_mom,2)+' b:'+STRTRIM(b_mom,2)
  XYOUTS,year(0),288,'MaxDev:'+STRTRIM(MAX(ABS(a_mom*yfit+b_mom-mom(fitst:fitend))))
   
  CLOSEDEVICE,d

 RETURN
 END

