; calculates the precession matrix between two epochs E0 and E1
; tj0  distance in Julian centuries from J2000.0 for E0
; tj1  distance in Julian centuries from J2000.0 for E1

 FUNCTION PRECESS,tj0,tj1,equatorial=equatorial,order=order,angarr=angarr

   IF N_ELEMENTS(tj1) LE 0 THEN tj1=tj0*0.0d
   IF NOT KEYWORD_SET(order) THEN order=3
   counts=N_ELEMENTS(tj0)

   stor=!dpi/(180.0d*3600.0d)
   dpi2=!dpi/2.0d
   pmat=DBLARR(counts,3,3)

   IF KEYWORD_SET(equatorial) THEN BEGIN

    ; S. 3.211.1
    theta=[[(2004.3109d)-0.85330d*tj0],[(-0.42665d)-0.000217d*tj0],[(-0.041833d)+tj0*0.0d]]
    dzeta=[[(2306.2181d)+1.39656d*tj0],[(0.30188d)-0.000344d*tj0],[(0.017998d)+tj0*0.0d]]
    zet  =[[(2306.2181d)+1.39656d*tj0],[(1.09468d)+0.000066d*tj0],[(0.018203d)+tj0*0.0d]]

    IF order GE 2 THEN BEGIN
     theta(*,0)=theta(*,0)-0.000217d*tj0*tj0
     dzeta(*,0)=dzeta(*,0)-0.000139d*tj0*tj0
     zet(*,0)  =zet(*,0)  -0.000139d*tj0*tj0
    ENDIF 

    tji=1.0d
    FOR i=0,order-1 DO BEGIN
      tji=tji*tj1 
      theta(*,i)=theta(*,i)*tji
      dzeta(*,i)=dzeta(*,i)*tji
      zet(*,i)  =zet(*,i)*tji
    ENDFOR

    stheta=TOTAL(theta,2)*stor
    sdzeta=TOTAL(dzeta,2)*stor
    szet  =TOTAL(zet,2)*stor
    FOR i=0l,counts-1l DO pmat(i,*,*)=GPOLROT(dpi2-sdzeta(i),stheta(i),-szet(i)-dpi2)
    angarr=[[stheta],[sdzeta],[szet]]

   ENDIF ELSE BEGIN
    
    ; S. 3.211.1
    pism =[[(47.0029d)-0.06603d*tj0]     ,[(-0.03302d)+0.000598*tj0 ],[(0.000060d)+tj0*0.0d]]
    pibig=[[(629554.982d)+3289.4789d*tj0],[(-869.8089d)-0.50491d*tj0],[(0.03536d)+tj0*0.0d]]
    pa   =[[(5029.0966d)+2.22226d*tj0]   ,[(1.11113d)-0.000042d*tj0 ],[(-0.000006d)+tj0*0.0d]]

    IF order GE 2 THEN BEGIN
     pism(*,0) =pism(*,0) +0.000598d*tj0*tj0
     pibig(*,0)=pibig(*,0)+0.60622d*tj0*tj0
     pa(*,0)   =pa(*,0)   -0.000042d*tj0*tj0
    ENDIF 

    tji=1.0d
    FOR i=0,order-1 DO BEGIN
      pibig(*,i)=pibig(*,i)*tji
      tji=tji*tj1 
      pism(*,i)=pism(*,i)*tji
      pa(*,i)  =pa(*,i)*tji

    ENDFOR

    spism=TOTAL(pism,2)*stor
    spibig=TOTAL(pibig,2)*stor
    spa  =TOTAL(pa,2)*stor
    FOR i=0l,counts-1l DO pmat(i,*,*)=GPOLROT(spibig(i),spism(i),-spa(i)-spibig(i))
    angarr=[[spism],[spibig],[spa]]
 
  ENDELSE


 RETURN,pmat
 END
