;+**********************************************************************
; SCCS id: %W% %U% %G% 
;***********************************************************************
; PROJECT: Cluster UK CDHF
;
; COMPONENT: QCDF_tools
;
; LANGUAGE:  IDL
;
; NAME: QCDF_EPOCH
;
; PURPOSE: as CDF_EPOCH but taking negative values also.
;
; CATEGORY: Epoch utilities.
;
; CALLING SEQUENCE:
;	value = QCDF_EPOCH(year,month,day[,hour,minute,second,msec])
;       
;
; INPUTS:  as CDF_EPOCH
;
; OPTIONAL INPUT PARAMETERS: hour,minute,second,msec are optional
;
; OUTPUTS: value  DOUBLE  epoch msecs
;
; RESTRICTIONS:
;
; PROCEDURE:  
;
; COPYRIGHT:
; ---------------------------------------------------------------------
; Copyright (c) 1996 W.J.M.Fraenz
;
; Astronomy Unit, Queen Mary and Westfield College, London, UK.
; This software is distributed WITHOUT ANY WARRANTY, and without even the
; implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
; You may copy or modify this software freely provided that you maintain a
; complete copy of this copyright message with the software.
; ---------------------------------------------------------------------
; MODIFICATION HISTORY:created 12/4/96 by M.Fraenz
;     procedure copied from EPOCH_COMPUTE by Anthony R Hare, March 1994.
;     
;-

FUNCTION QCDF_EPOCH,year,month,day,hour,minute,second,msec

IF N_ELEMENTS(msec) LE 0 THEN msec=0.0D
IF N_ELEMENTS(second) LE 0 THEN second=0.0D
IF N_ELEMENTS(minute) LE 0 THEN minute=0.0D
IF N_ELEMENTS(hour) LE 0 THEN hour=0.0D
y=LONG(year)
m=LONG(month)
d=LONG(day)

julian_date = LONG ( 367*y - 7*(y+(m+9)/12)/4 - 3*((y+(m-9)/7)/100+1)/4  $
                     + 275*m/9 + d + 1721029L )

msecs = DOUBLE(julian_date - 1721060L)
msecs = msecs * 24d0 + DOUBLE(hour)
msecs = msecs * 60d0 + DOUBLE(minute)
msecs = msecs * 60d0 + DOUBLE(second)
msecs = msecs * 1000d0 + DOUBLE(msec)


RETURN, msecs
END 
