;+**********************************************************************
; SCCS id: %W% %U% %G% 
;***********************************************************************
; PROJECT: Cluster UK CDHF
;
; COMPONENT: QVB
;
; LANGUAGE:  IDL
;
; NAME:
;	QCDF_STRTOEPO
;
; PURPOSE:
;       Convert a readable date-time string: "YYYY-MM-DD HH:MM:SS.MMM"
;       into CDF epoch format.
;
; CATEGORY:
;	Epoch utilities.
;
; CALLING SEQUENCE:
;	success = QCDF_STRTOEPO(epostrin,epochout)
;       
;
; INPUTS:  epostrin STRING in format YYYY-MM-DD HH:MM:SS.MMM
;                             or  YYYY-MM-DD
;                             or  YY-MM-DD
;
;
; KEYWORD PARAMETERS: /DATE  date input only
;                     MESID INT message id for INFO_MSG
;
; OUTPUTS: success    1 on sucess, 0 when concersion failed
;          epochout  DOUBLE CDF epoch time
;
;
; RESTRICTIONS:
;
; COPYRIGHT:
; ---------------------------------------------------------------------
; Copyright (c) 1996 W.J.M.Fraenz
;
; Astronomy Unit, Queen Mary and Westfield College, London, UK.
; This software is distributed WITHOUT ANY WARRANTY, and without even the
; implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
; You may copy or modify this software freely provided that you maintain a
; complete copy of this copyright message with the software.
; ---------------------------------------------------------------------
; MODIFICATION HISTORY:.
;     30/05/97 created MF
;-

FUNCTION QCDF_STRTOEPO, epostrin, EPOCH_OUT, date=date,MESID=mesid

ON_IOERROR,fail

  
   
  epostrin=STRTRIM(epostrin(0),2)
  epolen=STRLEN(epostrin)

  IF NOT KEYWORD_SET(date) THEN date=epolen LE 10
  IF STRPOS(epostrin,'-') EQ 2 THEN possub=2 ELSE possub=0

  year= LONG(STRMID(epostrin,0,4-possub))
  month=LONG(STRMID(epostrin,5-possub,2))
  day=LONG(STRMID(epostrin,8-possub,2))
  IF STRPOS(epostrin,'-') EQ 2 THEN BEGIN
   IF year LT 50 THEN year=year+2000 ELSE year=year+1900
  ENDIF
  hour=0
  minute=0
  second=0
  msec=0.0d
 IF  NOT KEYWORD_SET(date) THEN BEGIN
   hour= LONG(STRMID(epostrin,11-possub,2))
   IF epolen GT 12 THEN minute = LONG(STRMID(epostrin,14-possub,2))
   IF epolen GT 15 THEN second = LONG(STRMID(epostrin,17-possub,2))
   IF epolen GT 18 THEN msec= DOUBLE(STRMID(epostrin,20-possub,3))
 ENDIF

CDF_EPOCH,epoch_out,year,month,day,hour,minute,second,msec,/COMP


RETURN, 1b

fail:
 IF KEYWORD_SET(mesid) THEN $
   INFO_MSG,mesid,'Time conversion failed.',/error

RETURN,0b


END ;======================== end of epoch_string ======================
