
;
;
      PRO KEPLER,al,z,zto,r,u,ierr
;-----------------------------------------------------------------------
;
;     Object :
;     Kepler equation.
;     Inputs: al =  corrected mean longitude in radian
;             z  =  (e*cos(p),e*sin(p)) e:eccentricity, p:curly pi 
;             u  = 1/(1+sqrt(1-e^2))
;     Outputs: zto =(cos(w),sin(w)) where w=p+f f:true anomaly
;              r   =distance as factor of semi-major 
;
;     Error index :
;     ierr=0 : no error.
;     ierr=1 : error in algorithm.
;
;     Intrinsic complex functions :
;     dcmplex : complex number (*16) with two real numbers (*8).
;     dimag :   imaginary part (*8) of complex number (*16).
;     dreal :   real part (*8) of complex number (*16).
;     dconjg :  conjugate (*16) of complex number (*16).
;     cdabs :   absolute value (*8) of complex number (*16).
;     cdexp :   exponent (*16) of complex number (*16).
;
;-----------------------------------------------------------------------
;
      kmax=10
 
      k=0
      ierr=0
;
      al=al MOD (2*!dpi) ; lambda
      ex=ABS(z)          ; e
      z1=CONJ(z)         ; (ecos(p),-esin(p))
      e=al+(ex-0.125*ex^3)*sin(al)+0.5*ex^2*sin(2*al) $
       +0.375*ex^3*sin(al*3) ; E'=E+p
;
      WHILE 1b DO BEGIN
      k=k+1
      z2=DCOMPLEX(0.d0,e)    ; (0,E')
      zteta=EXP(z2)          ; (cosE',sinE')=
                             ; (cosEcos(p)-sinEsin(p),sinEcos(p)+cosEsin(p))
      z3=z1*zteta            ; (ecosE,esinE)
      dl=al-e+IMAGINARY(z3)  ; lambda-E'+esinE
      r=1-DOUBLE(z3)         ; r
      IF (ABS(dl) LT 1.d-12) THEN BEGIN
         z1=u*z*IMAGINARY(z3)   ; usinE(cos(p),sin(p))
         z2=DCOMPLEX(IMAGINARY(z1),-DOUBLE(z1)) ; usinE(sin(p),-cos(p))
         zto=(-z+zteta+z2)/r    ; (cos(w),sin(w))=
         ; =(cos(p)(cosE-e)-(1-u)sinEsin(p),sin(p)(cosE-e)+(1-u)sinEcos(p))
        RETURN
      ENDIF ELSE IF (k GT kmax) THEN BEGIN
            ierr=1
            RETURN
      ENDIF
      e=e+dl/r
      ENDWHILE
;
RETURN
END

