;####################DATA FROM F77 ROUTINE PLANETAP.F BY J.L. Simon
; see JL.Simon et al.,Astron&Astroph,282,663-683(1994)
 
; 1st order approx.

 PRO PLANEDAT1,ipla,t,a,dlm,e,pi,dinc,omega
;        Tables for mean elements.
;
;     Data tables :
;
;     The tables  a, dlm, e, pi, dinc, omega  give the mean elements of
;     classical Keplerian variables of planets limited to t^2 terms.
;     referred to the mean ecliptic and equinox of J2000. (5.8 in Simon et al)
;
;     - a:      semi-major axis,
;     - dlm :   mean longitude (degree and arcsecond),
;     - e :     eccentricity,
;     - pi :    longitude of the perihelion (degree and arcsecond),
;     - dinc :  inclination (degree and arcsecond),
;     - omega : longitude of the ascending node (degree and arcsecond).
;
;     The tables  kp, ca, sa  give the trigonometric terms to be added
;     to the mean elements of the semi-major axes.
;
;     The tables  kq, cl, sl  give the trigonometric terms to be added
;     to the mean elements of the mean longitudes.
;
;     Precision :
;
; 
 
 iplastr=['Mercury','Venus','EMB','Mars','Jupiter','Saturn','Uranus','Neptune', $
            'Pluto','Moon','Sun','Earth']

 dtor=!dpi/180d
 counts=N_ELEMENTS(t)
 a=DBLARR(counts)

CASE iplastr(ipla) OF
'Mercury':BEGIN  & a(*)=(0.38709831d) & e=2056318l+204d*t  & dlm=(252.2509055d)+149472.6746358d*t & END
'Venus':BEGIN    & a(*)=(0.72332982d) & e=67719l-478d*t  & dlm=(181.9798009d)+58517.8156760d*t & END
'EMB':BEGIN      & a(*)=(1.0000010d) & e=167086l-420d*t  & dlm=(100.4664568d)+35999.3728565d*t & END
'Mars':BEGIN     & a(*)=(1.5236793d) & e=934006l+905d*t  & dlm=(355.4329996d)+19140.2993039d*t & END
'Jupiter':BEGIN  & a(*)=(5.2026032d) & e=484979l+1632d*t &  dlm=(34.3515187d)+3034.9056606d*t & END
'Saturn':BEGIN   & a(*)=(9.5549092d) & e=555481l-3466d*t &  dlm=(50.0774443d)+1222.1138488d*t & END
'Uranus':BEGIN   & a(*)=(19.2184461d)  & e=463812l-273d*t  & dlm=(314.0550051d)+428.4669983d*t & END
'Neptune':BEGIN  & a(*)=(30.1103869d) & e=94557l+60d*t   & dlm=(304.3486655d)+218.4862002d*t & END
ENDCASE
e=e*1d-7

CASE iplastr(ipla) OF
'Mercury':BEGIN  &   pi=(77.4561190d)+0.1588643d*t & dinc=(7.0049863d)-0.0059516d*t & omega=(48.3308930d)-0.1254227d*t & END
'Venus':BEGIN    &  pi=(131.5637030d)+0.0048746d*t & dinc=(3.3946619d)-0.0008568d*t & omega=(76.6799202d)-0.2780134d*t & END
'EMB':BEGIN      &  pi=(102.9373481d)+0.3225654d*t & dinc=(0.0d)+0.0130548d*t & omega=(174.8731758d)-0.2410908d*t & END
'Mars':BEGIN     &  pi=(336.0602340d)+0.4439016d*t & dinc=(1.8497265d)-0.0081477d*t & omega=(49.5580932d)-0.2950250d*t & END
'Jupiter':BEGIN  &   pi=(14.3312069d)+0.2155209d*t & dinc=(1.3032670d)-0.0019877d*t & omega=(100.4644070d)+0.1767232d*t & END
'Saturn':BEGIN   &   pi=(93.0572375d)+0.5665415d*t & dinc=(2.4888788d)+0.0025514d*t & omega=(113.6655025d)-0.2566722d*t & END
'Uranus':BEGIN   &  pi=(173.0052911d)+0.0893212d*t & dinc=(0.7731969d)-0.0016869d*t & omega=(74.0059570d)+0.0741431d*t & END
'Neptune':BEGIN  &   pi=(48.1202755d)+0.0291866d*t & dinc=(1.7699526d)+0.0002256d*t & omega=(131.7840570d)-0.0061651d*t & END
ENDCASE
dlm=dlm*dtor & pi=pi*dtor & dinc=dinc*dtor & omega=omega*dtor

RETURN
END

