;+
; NAME: THPHV
;
; PURPOSE:
;	Transforms a vector or an array of vectors
;	from spherical to Cartesian coordinates.
;	
; CATEGORY: Coordinate Transformation
;
; CALLING SEQUENCE: v = THPHV(pos)
;
; INPUTS:
;	pos:    Array(n) of structures {theta,phi} in polar coordinates.
;
; OUTPUTS:
;	v:	Array (n,3) of vectors in Cartesian coordinates
;
; KEYWORD: geodeg 0/1 input in geographical degrees
;
; PROCEDURE:
;
; MODIFICATION HISTORY:
;       Based on PHTHRV, written by Markus Fraenz MPAE jan 1993
;       15/02/95 THPHV using a structure MKR
;       23/11/95 geodeg keyword MF
;
;-
FUNCTION THPHV,pos,geodeg=geodeg

IF KEYWORD_SET(geodeg) THEN BEGIN
  theta=(90.0d0 - pos.theta)*!DDTOR 
  phi=(pos.phi)*!DDTOR
ENDIF ELSE BEGIN
  theta=pos.theta
  phi=pos.phi
ENDELSE
st=sin(theta)
v=[[COS(phi)*st],[SIN(phi)*st],[COS(theta)]]
return,v
end
